@@ -1,9 +1,9 @@
-import pandas as pd
-import numpy as np
-from pgmpy.inference import VariableElimination
-from pgmpy.models import BayesianNetwork, NaiveBayes
-from pgmpy.estimators import ExhaustiveSearch, HillClimbSearch, TreeSearch
-from pgmpy.factors.discrete import TabularCPD
+# import pandas as pd
+# import numpy as np
+# from pgmpy.inference import VariableElimination
+# from pgmpy.models import BayesianNetwork, NaiveBayes
+# from pgmpy.estimators import ExhaustiveSearch, HillClimbSearch, TreeSearch
+# from pgmpy.factors.discrete import TabularCPD
 
 # %%
 import bnlearn as bn
@@ -12,6 +12,36 @@ import bnlearn as bn
 # print(dir(bn.parameter_learning))
 # print(dir(bn.inference))
 
+# %%
+# from pgmpy.estimators import BayesianEstimator
+# from pgmpy.utils import get_example_model
+# from pgmpy.models import BayesianNetwork
+# model = get_example_model('alarm')
+# df = model.simulate(int(1e4))
+
+# new_model = BayesianNetwork(model.edges())
+# cpds = BayesianEstimator(new_model, df).get_parameters(prior_type='dirichlet', pseudo_counts=1)
+# new_model.add_cpds(*cpds)
+ 
+# %% LOAD BIF FILE
+DAG = bn.import_DAG('water', verbose=0)
+# Sampling
+df = bn.sampling(DAG, n=1000)
+# Parameter learning
+model = bn.parameter_learning.fit(DAG, df, smooth=None)
+
+# %%
+import bnlearn as bn
+df = bn.import_example('asia')
+model = bn.structure_learning.fit(df)
+bn.plot(model)
+bn.plot(model, params_static={'layout':'spectral_layout'})
+bn.plot(model, params_static={'layout':'planar_layout'})
+bn.plot(model, params_static={'layout':'kamada_kawai_layout'})
+bn.plot(model, params_static={'layout':'spring_layout'})
+bn.plot(model, params_static={'layout':'circular_layout', "figsize": (15, 10)})
+
+
 # %%
 
 # Load example dataset
@@ -29,7 +59,7 @@ bn.print_CPD(DAG)
 
 model = bn.parameter_learning.fit(DAG, df, verbose=3)
 bn.print_CPD(model)
-
+bn.plot(model)
 
 # %%
 import bnlearn as bn
@@ -58,6 +88,8 @@ df = bn.vec2df(raw['source'], raw['target'], raw['weight'])
 DAG = bn.make_DAG(list(zip(raw['source'], raw['target'])), verbose=0)
 # Make plot
 bn.plot(DAG, interactive=True)
+bn.plot(DAG, interactive=False)
+
 # Parameter learning
 model = bn.parameter_learning.fit(DAG, df, verbose=3)
 # Structure learning
@@ -67,6 +99,13 @@ DAG_learned = bn.independence_test(DAG_learned, df, prune=True)
 # Plot
 bn.plot(DAG_learned, interactive=True)
 
+fig_properties = bn.plot(model, params_static={'layout':'spectral_layout'})
+fig_properties = bn.plot(model, params_static={'layout':'planar_layout'})
+fig_properties = bn.plot(model, params_static={'layout':'kamada_kawai_layout', 'figsize':(25,15)})
+fig_properties = bn.plot(model, params_static={'layout':'spring_layout'})
+fig_properties = bn.plot(model, params_static={'layout':'circular_layout'})
+
+
 # Generate some data based on DAG
 # df1 = bn.sampling(model, n=1000)
 # Make predictions
@@ -110,6 +149,10 @@ print(adjmat.sum(axis=0))
 DAG_1 = bn.import_DAG('sprinkler', verbose=0)
 graph = bn.plot(DAG_1)
 
+graph = bn.plot(DAG_1, params_static={'layout':'kamada_kawai_layout'})
+graph = bn.plot(DAG_1, params_static={'layout':'spring_layout'})
+
+
 # Example 2: Download small spinkler example with 1000 samples
 df = bn.import_example('sprinkler')
 DAG_2 = bn.structure_learning.fit(df)
